@@ -17,29 +17,19 @@
  *									* 
  ************************************************************************/
 
-/* $Id: utils.c,v 1.1 1996/02/11 20:44:55 david Rel david $
- * $Log: utils.c,v $
- * Revision 1.1  1996/02/11 20:44:55  david
- * Initial revision
- * */
-
 #include <stdio.h>
 #include <stdlib.h>
+#include <errno.h>
 
 #define LINEFRAGMENT 32
 
-extern int errno;
-extern char *progname;
-
 void *xmalloc(size_t size)	/* safe malloc */
 {
   void *ptr;
 
-  errno=0;
   ptr=malloc(size);
-  if ((ptr == NULL) || (errno != 0))
-  {
-    perror(progname); exit(1); 
+  if (ptr == NULL) {
+    perror("xmalloc"); exit(1); 
   }
 
   return ptr;
@@ -47,11 +37,9 @@ void *xmalloc(size_t size)	/* safe malloc */
 
 void *xrealloc(void *ptr, size_t size)
 {
-  errno=0;
   ptr=realloc(ptr, size);
-  if (ptr == NULL) 
-  {
-    perror(progname); exit(1); 
+  if (ptr == NULL) {
+    perror("xrealloc"); exit(1); 
   }
 
   return ptr;
@@ -61,23 +49,19 @@ unsigned char *getline(FILE *stream)
 /* Read a line of text without imposing an length limit */
 /* From: Bison Manual */
 {
-  unsigned char *line=NULL;
+  unsigned char *line;
   int c;
   int i;
 
-  i=0; errno=0;
-  line=(unsigned char *)xmalloc(LINEFRAGMENT+1);
-  while (((c = fgetc(stream)) != EOF) && (c != '\n') && (c != '\0'))
-  {
-    if (errno != 0) perror(progname);
-
-    if ((i > LINEFRAGMENT) &&  (i % LINEFRAGMENT) == 0) 
-    line=(unsigned char *)xrealloc(line,i+LINEFRAGMENT+1);
-    line[i]=c; i++;
+  line=(unsigned char *)xmalloc(LINEFRAGMENT+1); i=0;
+  while (((c=fgetc(stream)) != EOF) && (c != '\n')) {
+    if ((i > LINEFRAGMENT) && (i % LINEFRAGMENT) == 0) 
+      line=(unsigned char *)xrealloc(line,i+LINEFRAGMENT+1);
+    line[i++]=c;
   }
-  if ((c != EOF) && (c != '\0')) line[i]='\0';
-  else
-  {
+  line[i]='\0';
+
+  if (c == EOF) {
     free(line); line=NULL;
   }
   return line;
